==> tine20-allinone_2019.12.5.tar.bz2: ActiveSync/js/ActiveSync-lang-sv_SE-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of ActiveSync **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/ActiveSync'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2017-09-28 09:48+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Swedish (Sweden) (http://www.transifex.com/tine20/tine20/language/sv_SE/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: sv_SE\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "SyncDevice, SyncDevices"
: [
  ""
 ,""

]
, "Sync Devices"
: ""

, "ID"
: ""

, "Device ID"
: ""

, "Devicetype"
: ""

, "Owner"
: ""

, "Policy"
: ""

, "AS Version"
: ""

, "Useragent"
: ""

, "Model"
: ""

, "IMEI"
: ""

, "Friendly Name"
: ""

, "OS"
: ""

, "OS Language"
: ""

, "Phonenumber"
: ""

, "Ping Lifetime"
: ""

, "Ping Folder"
: ""

, "Remote Wipe"
: ""

, "Calendarfilter"
: ""

, "Contactsfilter"
: ""

, "Emailfilter"
: ""

, "Tasksfilter"
: ""

, "Last Ping"
: ""

, "Remote Reset Device"
: ""

, "Please Confirm"
: ""

, "Do you really want to wipe the selected devices? All personal data will be removed and the device is reset to factory settings!"
: ""

, "Quicksearch"
: ""

, "Device, Devices"
: [
  "Enhet"
 ,"Enheter"

]
, "Devices"
: "Enheter"

, "Active Sync"
: "Aktiv "

, "Select a Device"
: "Välj en Enhet"

, "No ActiveSync Device registered"
: "Ingen AktivSynk Enhet registrerad"

, "Set as {0} Filter"
: "Ange som {0} Filter"

, "Resetted Sync Filter"
: "Återställt Synk filter"

, "{0} filter for device \"{1}\" is now \"{2}\""
: "{0} filter för enhet \"{1}\" är nu \"{2}\""

, "resetted"
: "Återställd"

, "Set Sync Filter"
: "Ange Synk Filter"

, "Default Addressbook"
: "Standard Adressbok"

, "The default addressbook to create new contacts in."
: "Standard adressboken för att skapa nya kontakter i."

, "Default Calendar"
: "Standard Kalender"

, "The default calendar to create new events in."
: "Standard Kalendern för att skapa nya händelser i. "

, "Default Task List"
: "Standard Uppgift Lista"

, "The default task list to create new tasks in."
: "Standard uppgiftslista för att skapa nya uppgifter i."

, "Default policy for new devices"
: "Standardpolicy för nya enheter"

, "Enter the id of the policy to apply to newly created devices."
: "Ange id för den policy som skall appliceras för nyligen skapta enheter."

, "Disable Access Log"
: ""

, "Disable ActiveSync Access Log creation."
: ""

, "Filter timeslot for emails"
: ""

, "For how long in the past the emails should be synchronized."
: ""

, "Filter timeslot for events"
: ""

, "For how long in the past the events should be synchronized."
: ""

, "Manage ActiveSync devices"
: ""

, "See, edit and delete ActiveSync devices"
: ""

, "Reset ActiveSync devices"
: ""

, "Remotely reset ActiveSync devices to factory state, deleting all data"
: ""

, "Default Policy"
: "Standard Policy"

, "Default Policy installed during setup"
: "Standard Policy installerad under installation"

, "SyncDevice"
: ""

, "Device"
: "Enhet"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2020.03.4.tar.bz2: ActiveSync/js/ActiveSync-lang-sv_SE-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of ActiveSync **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/ActiveSync'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2017-09-28 09:48+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Swedish (Sweden) (http://www.transifex.com/tine20/tine20/language/sv_SE/)\nLanguage: sv_SE\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Default Address book"
: ""

, "The default address book to create new contacts in."
: ""

, "Default Calendar"
: "Standard Kalender"

, "The default calendar to create new events in."
: "Standard Kalendern för att skapa nya händelser i. "

, "Default Task List"
: "Standard Uppgift Lista"

, "The default task list to create new tasks in."
: "Standard uppgiftslista för att skapa nya uppgifter i."

, "Sync Devices"
: ""

, "Device ID"
: ""

, "Devicetype"
: ""

, "Owner"
: ""

, "Policy"
: ""

, "ActiveSync Version"
: ""

, "User agent"
: ""

, "Model"
: ""

, "IMEI"
: ""

, "Friendly Name"
: ""

, "OS"
: ""

, "OS Language"
: ""

, "Phonenumber"
: ""

, "Sync Device, Sync Devices"
: [
  ""
 ,""

]
, "Device, Devices"
: [
  "Enhet"
 ,"Enheter"

]
, "Devices"
: "Enheter"

, "Active Sync"
: "Aktiv "

, "Select a Device"
: "Välj en Enhet"

, "No ActiveSync Device registered"
: "Ingen AktivSynk Enhet registrerad"

, "Set as {0} Filter"
: "Ange som {0} Filter"

, "Resetted Sync Filter"
: "Återställt Synk filter"

, "{0} filter for device \"{1}\" is now \"{2}\""
: "{0} filter för enhet \"{1}\" är nu \"{2}\""

, "resetted"
: "Återställd"

, "Set Sync Filter"
: "Ange Synk Filter"

, "ID"
: ""

, "Device Type"
: ""

, "Operating System"
: ""

, "Phone Number"
: ""

, "Ping Lifetime"
: ""

, "Ping Folder"
: ""

, "Remote Wipe"
: ""

, "Calendar Filter"
: ""

, "Contacts Filter"
: ""

, "E-mail Filter"
: ""

, "Tasks Filter"
: ""

, "Last Ping"
: ""

, "Monitor Last Ping"
: ""

, "Remote Device Reset"
: ""

, "Please Confirm"
: ""

, "Do you really want to wipe the selected devices? All personal data will be removed and the device will be reset to factory settings!"
: ""

, "Quicksearch"
: ""

, "Default Policy"
: "Standard Policy"

, "Default Policy installed during setup"
: "Standard Policy installerad under installation"

, "Default policy for new devices"
: "Standardpolicy för nya enheter"

, "Enter the id of the policy to apply to newly created devices."
: "Ange id för den policy som skall appliceras för nyligen skapta enheter."

, "User Agent Deny List"
: ""

, "Array of regular expressions of User-Agent strings"
: ""

, "Disable Access Log"
: ""

, "Disable ActiveSync Access Log creation."
: ""

, "Filter timeslot for e-mails"
: ""

, "For how long in the past the e-mails should be synchronized."
: ""

, "Filter timeslot for events"
: ""

, "For how long in the past the events should be synchronized."
: ""

, "Manage ActiveSync devices"
: ""

, "See, edit and delete ActiveSync devices"
: ""

, "Reset ActiveSync devices"
: ""

, "Remotely reset ActiveSync devices to factory state, deleting all data"
: ""



, "Sync Device"
: ""

, "Device"
: "Enhet"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
